@@ -4,8 +4,8 @@
 ;;               2022–2025 anki-editor contributors
 
 ;; Author: Lei Tan
-;; Package-Version: 20251222.1345
-;; Package-Revision: 59d75f6b6b63
+;; Package-Version: 20260108.1020
+;; Package-Revision: d50f9e35015d
 ;; URL: https://github.com/anki-editor/anki-editor
 ;; Package-Requires: ((emacs "29.1"))
 
@@ -1544,6 +1544,16 @@ matching non-empty `ANKI_FAILURE_REASON' properties."
   (anki-editor-push-notes scope
                           (concat anki-editor-prop-failure-reason "<>\"\"")))
 
+(defun anki-editor-force-push-notes (&optional scope)
+  "Push all notes in SCOPE to anki, regardless of the current
+value of `anki-editor-force-update' or whether note contents
+have changed."
+  (interactive)
+  ;; use dynamic scoped var so we don't change anki-editor-push-notes
+  ;; signature.
+  (let ((anki-editor-force-update t))
+    (anki-editor-push-notes scope)))
+
 (defun anki-editor-delete-note-at-point (&optional prefix)
   "Delete the note at point from Anki.
 With PREFIX also delete it from Org."
